@@ -1,4 +1,4 @@
-﻿(function ($, document) {
+﻿define(['jQuery'], function ($) {
 
     function getView() {
 
@@ -63,7 +63,8 @@
                     centerText: true,
                     lazy: true,
                     overlayText: false,
-                    showDetailsMenu: true
+                    showDetailsMenu: true,
+                    overlayPlayButton: true
                 });
             }
 
@@ -195,7 +196,8 @@
                 shape: getPortraitShape(),
                 centerText: true,
                 lazy: true,
-                showDetailsMenu: true
+                showDetailsMenu: true,
+                overlayPlayButton: true
             });
         }
         html += '</div>';
@@ -282,7 +284,6 @@
                 break;
             case 1:
                 depends.push('scripts/movies');
-                depends.push('scripts/queryfilters');
                 renderMethod = 'renderMoviesTab';
                 initMethod = 'initMoviesTab';
                 break;
@@ -332,7 +333,7 @@
         $('.recommendations', page).createCardMenus();
 
         var tabs = page.querySelector('paper-tabs');
-        var pages = page.querySelector('neon-animated-pages');
+        var pageTabsContainer = page.querySelector('.pageTabsContainer');
 
         var baseUrl = 'movies.html';
         var topParentId = LibraryMenu.getTopParentId();
@@ -340,10 +341,10 @@
             baseUrl += '?topParentId=' + topParentId;
         }
 
-        LibraryBrowser.configurePaperLibraryTabs(page, tabs, pages, baseUrl);
+        LibraryBrowser.configurePaperLibraryTabs(page, tabs, pageTabsContainer, baseUrl);
 
-        pages.addEventListener('tabchange', function (e) {
-            loadTab(page, parseInt(e.target.selected));
+        pageTabsContainer.addEventListener('tabchange', function (e) {
+            loadTab(page, parseInt(e.detail.selectedTabIndex));
         });
     });
 
@@ -370,23 +371,27 @@
             }
         }
 
-        $(MediaController).on('playbackstop', onPlaybackStop);
+        Events.on(MediaController, 'playbackstop', onPlaybackStop);
     });
 
     pageIdOn('pagebeforehide', "moviesPage", function () {
 
         var page = this;
-        $(MediaController).off('playbackstop', onPlaybackStop);
+        Events.off(MediaController, 'playbackstop', onPlaybackStop);
     });
 
     function onPlaybackStop(e, state) {
 
         if (state.NowPlayingItem && state.NowPlayingItem.MediaType == 'Video') {
             var page = $($.mobile.activePage)[0];
-            var pages = page.querySelector('neon-animated-pages');
+            var pageTabsContainer = page.querySelector('.pageTabsContainer');
 
-            pages.dispatchEvent(new CustomEvent("tabchange", {}));
+            pageTabsContainer.dispatchEvent(new CustomEvent("tabchange", {
+                detail: {
+                    selectedTabIndex: libraryBrowser.selectedTabIndex(pageTabsContainer)
+                }
+            }));
         }
     }
 
-})(jQuery, document);
\ No newline at end of file
+});
\ No newline at end of file
